#!/usr/bin/python

from alfred.decorator import command, option
from alfred.main import call, invoke_command, run, sh
